#include <curl/curl.h>

#include <iostream>
#include <vector>
#include "histogram.h"
#include "text.h"
#include "svg.h"

using namespace std;

struct Input
{
    vector<double> numbers;
    size_t bin_count{};
};


Input input_data(istream& in, bool prompt = true) {  //   prompt    
    Input data;
    size_t number_count;

    if (prompt) {
        cerr << "Enter number count: ";
    }
    in >> number_count;

    data.numbers.resize(number_count);
    if (prompt) {
        cerr << "Enter numbers: ";
    }
    for (size_t i = 0; i < number_count; i++) {
        in >> data.numbers[i];
    }

    if (prompt) {
        cerr << "Enter number of bins: ";
    }
    in >> data.bin_count;

    return data;
}


// Callback-    
static size_t WriteCallback(void* contents, size_t size, size_t nmemb, void* userp) {
    ((string*)userp)->append((char*)contents, size * nmemb);
    return size * nmemb;
}


int main(int argc, char* argv[]) {
    if (argc > 1) {
        CURL* curl = curl_easy_init();
        if(curl) {
            CURLcode res;
            string readBuffer;

            //  URL     
            curl_easy_setopt(curl, CURLOPT_URL, argv[1]);
            //  callback-   
            curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, WriteCallback);
            //     
            curl_easy_setopt(curl, CURLOPT_WRITEDATA, &readBuffer);

            //  

               //   SSL (  !)
            curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 0L);
            curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 0L);
            res = curl_easy_perform(curl);
            if(res != CURLE_OK) {
                cerr << "curl_easy_perform() failed: " << curl_easy_strerror(res) << endl;
            } else {
                //   
                cout << readBuffer;
            }

            //   cURL
            curl_easy_cleanup(curl);
            return 0;
        }
    }
    curl_global_init(CURL_GLOBAL_ALL);
    size_t max_count;
    auto in = input_data(cin);
    auto bins = make_histogram(in.numbers, in.bin_count);
    show_histogram_svg(bins);
}







